package fr.mael.jiwigo.ui.mainframe.thread;

import java.io.File;

import javax.swing.JOptionPane;

import fr.mael.jiwigo.transverse.ImagesManagement;
import fr.mael.jiwigo.transverse.enumeration.PreferencesEnum;
import fr.mael.jiwigo.transverse.exception.FileAlreadyExistsException;
import fr.mael.jiwigo.transverse.exception.WrongChunkSizeException;
import fr.mael.jiwigo.transverse.util.Messages;
import fr.mael.jiwigo.transverse.util.preferences.PreferencesManagement;
import fr.mael.jiwigo.transverse.util.spring.SpringUtils;
import fr.mael.jiwigo.ui.mainframe.MainFrame;
import fr.mael.jiwigo.ui.mainframe.ThumbnailCategoryPanel;

/**
   Copyright (c) 2010, Mael
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of jiwigo nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
   DISCLAIMED. IN NO EVENT SHALL Mael BE LIABLE FOR ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * @author mael
 * Thread that send the photos
 */
public class ThreadPhotoSending implements Runnable {
    private File[] files;
    private ThumbnailCategoryPanel thumbPanel;

    public ThreadPhotoSending(File[] files, ThumbnailCategoryPanel thumbPanel) {
	this.files = files;
	this.thumbPanel = thumbPanel;
    }

    @Override
    public void run() {

	for (int i = 0; i < files.length; i++) {
	    int nbProgressBar = ((i + 1) * 100) / files.length;
	    try {
		Integer widthOriginal = Integer.valueOf(PreferencesManagement.getValue(PreferencesEnum.WIDTH_ORIGINALE
			.getLabel()));
		Integer heightOriginal = Integer.valueOf(PreferencesManagement.getValue(PreferencesEnum.HEIGHT_ORIGINAL
			.getLabel()));
		Double chunkSize = Double
			.valueOf(PreferencesManagement.getValue(PreferencesEnum.CHUNK_SIZE.getLabel()));
		MainFrame.getInstance().setAdditionalMessage(
			Messages.getMessage("file") + " " + (i + 1) + "/" + files.length + " : ");
		SpringUtils.getImageService().create(files[i].getCanonicalPath(), thumbPanel.getCategoryId(),
			widthOriginal, heightOriginal, chunkSize, ImagesManagement.getInstance().getPrivacyLevel());
		MainFrame.getInstance().setMessage(files[i].getName() + " " + Messages.getMessage("sendingSuccess"));
	    } catch (FileAlreadyExistsException e) {
		//displays a dialog if there is a FileAlreadyExistsException
		JOptionPane.showMessageDialog(null, Messages.getMessage("fileAlreadyExistsError"), Messages
			.getMessage("error"), JOptionPane.ERROR_MESSAGE);
		MainFrame.getInstance().setMessage(Messages.getMessage("sendingError") + " " + files[i].getName());
	    } catch (WrongChunkSizeException e) {
		JOptionPane.showMessageDialog(null, Messages.getMessage("wrongChunkSizeError") + files[i].getName(),
			Messages.getMessage("error"), JOptionPane.ERROR_MESSAGE);
		MainFrame.getInstance().setMessage(Messages.getMessage("sendingError") + " " + files[i].getName());
	    } catch (Exception e) {
		JOptionPane.showMessageDialog(null, Messages.getMessage("sendingError") + files[i].getName(), Messages
			.getMessage("error"), JOptionPane.ERROR_MESSAGE);
		MainFrame.getInstance().setMessage(Messages.getMessage("sendingError") + " " + files[i].getName());
	    } finally {
		MainFrame.getInstance().getProgressBar().setValue(nbProgressBar);
	    }
	}
	MainFrame.getInstance().setAdditionalMessage("");
	//refresh
	thumbPanel.refresh(thumbPanel.getCategoryId(), true);
	MainFrame.getInstance().getProgressBar().setValue(0);
    }
}
